summaryrefslogtreecommitdiff
path: root/lib/tdb/common/lock.c
diff options
context:
space:
mode:
authorRusty Russell <rusty@rustcorp.com.au>2010-02-17 12:19:47 +1030
committerRusty Russell <rusty@rustcorp.com.au>2010-02-17 12:19:47 +1030
commite9114a758538d460d4f9deae5ce631bf44b1eff8 (patch)
treee56ad1e44f421d278bb467d6d83e1deeccd9b8bb /lib/tdb/common/lock.c
parent7ab422d6fbd4f8be02838089a41f872d538ee7a7 (diff)
downloadsamba-e9114a758538d460d4f9deae5ce631bf44b1eff8.tar.gz
samba-e9114a758538d460d4f9deae5ce631bf44b1eff8.tar.bz2
samba-e9114a758538d460d4f9deae5ce631bf44b1eff8.zip
tdb: cleanup: rename global_lock to allrecord_lock.
The word global is overloaded in tdb. The global_lock inside struct tdb_context is used to indicate we hold a lock across all the chains. Rename it to allrecord_lock. Signed-off-by: Rusty Russell <rusty@rustcorp.com.au>
Diffstat (limited to 'lib/tdb/common/lock.c')
-rw-r--r--lib/tdb/common/lock.c42
1 files changed, 21 insertions, 21 deletions
diff --git a/lib/tdb/common/lock.c b/lib/tdb/common/lock.c
index 515bffee59..6b320f45fe 100644
--- a/lib/tdb/common/lock.c
+++ b/lib/tdb/common/lock.c
@@ -226,13 +226,13 @@ static int _tdb_lock(struct tdb_context *tdb, int list, int ltype,
struct tdb_lock_type *new_lck;
int i;
- /* a global lock allows us to avoid per chain locks */
- if (tdb->global_lock.count &&
- (ltype == tdb->global_lock.ltype || ltype == F_RDLCK)) {
+ /* a allrecord lock allows us to avoid per chain locks */
+ if (tdb->allrecord_lock.count &&
+ (ltype == tdb->allrecord_lock.ltype || ltype == F_RDLCK)) {
return 0;
}
- if (tdb->global_lock.count) {
+ if (tdb->allrecord_lock.count) {
tdb->ecode = TDB_ERR_LOCK;
return -1;
}
@@ -318,12 +318,12 @@ static int _tdb_unlock(struct tdb_context *tdb, int list, int ltype,
struct tdb_lock_type *lck = NULL;
/* a global lock allows us to avoid per chain locks */
- if (tdb->global_lock.count &&
- (ltype == tdb->global_lock.ltype || ltype == F_RDLCK)) {
+ if (tdb->allrecord_lock.count &&
+ (ltype == tdb->allrecord_lock.ltype || ltype == F_RDLCK)) {
return 0;
}
- if (tdb->global_lock.count) {
+ if (tdb->allrecord_lock.count) {
tdb->ecode = TDB_ERR_LOCK;
return -1;
}
@@ -403,7 +403,7 @@ int tdb_unlock(struct tdb_context *tdb, int list, int ltype)
*/
int tdb_transaction_lock(struct tdb_context *tdb, int ltype)
{
- if (tdb->global_lock.count) {
+ if (tdb->allrecord_lock.count) {
return 0;
}
if (tdb->transaction_lock_count > 0) {
@@ -426,7 +426,7 @@ int tdb_transaction_lock(struct tdb_context *tdb, int ltype)
int tdb_transaction_unlock(struct tdb_context *tdb, int ltype)
{
int ret;
- if (tdb->global_lock.count) {
+ if (tdb->allrecord_lock.count) {
return 0;
}
if (tdb->transaction_lock_count > 1) {
@@ -453,12 +453,12 @@ static int _tdb_lockall(struct tdb_context *tdb, int ltype,
return -1;
}
- if (tdb->global_lock.count && tdb->global_lock.ltype == ltype) {
- tdb->global_lock.count++;
+ if (tdb->allrecord_lock.count && tdb->allrecord_lock.ltype == ltype) {
+ tdb->allrecord_lock.count++;
return 0;
}
- if (tdb->global_lock.count) {
+ if (tdb->allrecord_lock.count) {
/* a global lock of a different type exists */
tdb->ecode = TDB_ERR_LOCK;
return -1;
@@ -479,8 +479,8 @@ static int _tdb_lockall(struct tdb_context *tdb, int ltype,
return -1;
}
- tdb->global_lock.count = 1;
- tdb->global_lock.ltype = ltype;
+ tdb->allrecord_lock.count = 1;
+ tdb->allrecord_lock.ltype = ltype;
return 0;
}
@@ -496,13 +496,13 @@ static int _tdb_unlockall(struct tdb_context *tdb, int ltype, bool mark_lock)
return -1;
}
- if (tdb->global_lock.ltype != ltype || tdb->global_lock.count == 0) {
+ if (tdb->allrecord_lock.ltype != ltype || tdb->allrecord_lock.count == 0) {
tdb->ecode = TDB_ERR_LOCK;
return -1;
}
- if (tdb->global_lock.count > 1) {
- tdb->global_lock.count--;
+ if (tdb->allrecord_lock.count > 1) {
+ tdb->allrecord_lock.count--;
return 0;
}
@@ -513,8 +513,8 @@ static int _tdb_unlockall(struct tdb_context *tdb, int ltype, bool mark_lock)
return -1;
}
- tdb->global_lock.count = 0;
- tdb->global_lock.ltype = 0;
+ tdb->allrecord_lock.count = 0;
+ tdb->allrecord_lock.ltype = 0;
return 0;
}
@@ -637,7 +637,7 @@ int tdb_chainunlock_read(struct tdb_context *tdb, TDB_DATA key)
/* record lock stops delete underneath */
int tdb_lock_record(struct tdb_context *tdb, tdb_off_t off)
{
- if (tdb->global_lock.count) {
+ if (tdb->allrecord_lock.count) {
return 0;
}
return off ? tdb->methods->brlock(tdb, F_RDLCK, off, 1, TDB_LOCK_WAIT) : 0;
@@ -668,7 +668,7 @@ int tdb_unlock_record(struct tdb_context *tdb, tdb_off_t off)
struct tdb_traverse_lock *i;
uint32_t count = 0;
- if (tdb->global_lock.count) {
+ if (tdb->allrecord_lock.count) {
return 0;
}